Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/roundcube/roundcubemail.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorAleksander Machniak <alec@alec.pl>2021-01-01 13:24:16 +0300
committerAleksander Machniak <alec@alec.pl>2021-01-01 13:24:16 +0300
commit0cd377a20b9035801a9a231149623befcd4d8492 (patch)
treea4af31319eb9c95221bd29909b1ad2b395b7c5f8 /.ci/install.sh
parent10c3c533550a952c9976044d2600a7b1d287c9cd (diff)
Travis: Use minified js files in browser tests
Diffstat (limited to '.ci/install.sh')
-rwxr-xr-x.ci/install.sh10
1 files changed, 7 insertions, 3 deletions
diff --git a/.ci/install.sh b/.ci/install.sh
index 763fa2ff5..5ea97338d 100755
--- a/.ci/install.sh
+++ b/.ci/install.sh
@@ -24,9 +24,13 @@ if [[ ${TRAVIS_PHP_VERSION:0:1} == "8" ]]; then composer config platform.php 7.4
# Install PHP dependencies
composer install --prefer-dist
-# Install Less for Elastic CSS compilation
-npm install --force -g less
-npm install --force -g less-plugin-clean-css
+# Install Less for Elastic CSS compilation, and UglifyJS for JS files minification
+if [ "$BROWSER_TESTS" = 1 ]
+then
+ npm install --force -g less
+ npm install --force -g less-plugin-clean-css
+ npm install --force -g uglify-js
+fi
# Roundcube tests and instance configuration
cp .ci/config-test.inc.php config/config-test.inc.php